==> avahi-0.6.22-i586-P1.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf bshell )
( cd usr/bin ; ln -sf bssh bshell )
( cd usr/bin ; rm -rf avahi-resolve-address )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-address )
( cd usr/bin ; rm -rf avahi-publish-address )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-address )
( cd usr/bin ; rm -rf bvnc )
( cd usr/bin ; ln -sf bssh bvnc )
( cd usr/bin ; rm -rf avahi-browse-domains )
( cd usr/bin ; ln -sf avahi-browse avahi-browse-domains )
( cd usr/bin ; rm -rf avahi-resolve-host-name )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-host-name )
( cd usr/bin ; rm -rf avahi-publish-service )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-service )
( cd usr/lib ; rm -rf libavahi-glib.so )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so )
( cd usr/lib ; rm -rf libavahi-core.so.5 )
( cd usr/lib ; ln -sf libavahi-core.so.5.0.4 libavahi-core.so.5 )
( cd usr/lib ; rm -rf libdns_sd.so )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so )
( cd usr/lib ; rm -rf libhowl.so )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so )
( cd usr/lib ; rm -rf libavahi-gobject.so.0 )
( cd usr/lib ; ln -sf libavahi-gobject.so.0.0.0 libavahi-gobject.so.0 )
( cd usr/lib ; rm -rf libavahi-core.so )
( cd usr/lib ; ln -sf libavahi-core.so.5.0.4 libavahi-core.so )
( cd usr/lib ; rm -rf libavahi-common.so )
( cd usr/lib ; ln -sf libavahi-common.so.3.5.0 libavahi-common.so )
( cd usr/lib ; rm -rf libavahi-ui.so )
( cd usr/lib ; ln -sf libavahi-ui.so.0.1.0 libavahi-ui.so )
( cd usr/lib ; rm -rf libavahi-qt4.so.1 )
( cd usr/lib ; ln -sf libavahi-qt4.so.1.0.1 libavahi-qt4.so.1 )
( cd usr/lib ; rm -rf libdns_sd.so.1 )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so.1 )
( cd usr/lib ; rm -rf libavahi-ui.so.0 )
( cd usr/lib ; ln -sf libavahi-ui.so.0.1.0 libavahi-ui.so.0 )
( cd usr/lib ; rm -rf libhowl.so.0 )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so.0 )
( cd usr/lib ; rm -rf libavahi-client.so )
( cd usr/lib ; ln -sf libavahi-client.so.3.2.4 libavahi-client.so )
( cd usr/lib ; rm -rf libavahi-client.so.3 )
( cd usr/lib ; ln -sf libavahi-client.so.3.2.4 libavahi-client.so.3 )
( cd usr/lib ; rm -rf libavahi-common.so.3 )
( cd usr/lib ; ln -sf libavahi-common.so.3.5.0 libavahi-common.so.3 )
( cd usr/lib ; rm -rf libavahi-gobject.so )
( cd usr/lib ; ln -sf libavahi-gobject.so.0.0.0 libavahi-gobject.so )
( cd usr/lib ; rm -rf libavahi-glib.so.1 )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so.1 )
( cd usr/lib ; rm -rf libavahi-qt4.so )
( cd usr/lib ; ln -sf libavahi-qt4.so.1.0.1 libavahi-qt4.so )
( cd usr/share/man/man1 ; rm -rf avahi-browse-domains.1 )
( cd usr/share/man/man1 ; ln -sf avahi-browse.1 avahi-browse-domains.1 )
( cd usr/share/man/man1 ; rm -rf avahi-publish-service.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1.gz avahi-publish-service.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-publish-address.1 )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1 avahi-publish-address.1 )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-address.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1.gz avahi-resolve-address.1.gz )
( cd usr/share/man/man1 ; rm -rf bvnc.1.gz )
( cd usr/share/man/man1 ; ln -sf bssh.1.gz bvnc.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-host-name.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1.gz avahi-resolve-host-name.1.gz )
#%% begin initialize avahi-0.6.22-i586-P1
chk=`grep avahi /etc/passwd`  
if [ "$chk.x" == ".x" ]; then
    useradd -d /dev/null -s /usr/sbin/avahi-daemmon -u 112 avahi
fi

chk=`grep avahi /etc/group` 
if [ "$chk.x" == ".x" ]; then
    groupradd -g 112 avahi
fi

chk=`grep netdev /etc/group`
if [ "$chk.x" == ".x" ]; then
    groupadd -g 113 netdev
fi

#%% end

==> avahi-0.6.23-i586-P1.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf avahi-resolve-address )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-address )
( cd usr/bin ; rm -rf bvnc )
( cd usr/bin ; ln -sf bssh bvnc )
( cd usr/bin ; rm -rf avahi-browse-domains )
( cd usr/bin ; ln -sf avahi-browse avahi-browse-domains )
( cd usr/bin ; rm -rf avahi-publish-address )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-address )
( cd usr/bin ; rm -rf bshell )
( cd usr/bin ; ln -sf bssh bshell )
( cd usr/bin ; rm -rf avahi-publish-service )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-service )
( cd usr/bin ; rm -rf avahi-resolve-host-name )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-host-name )
( cd usr/lib ; rm -rf libavahi-qt4.so.1 )
( cd usr/lib ; ln -sf libavahi-qt4.so.1.0.2 libavahi-qt4.so.1 )
( cd usr/lib ; rm -rf libavahi-gobject.so.0 )
( cd usr/lib ; ln -sf libavahi-gobject.so.0.0.1 libavahi-gobject.so.0 )
( cd usr/lib ; rm -rf libavahi-ui.so )
( cd usr/lib ; ln -sf libavahi-ui.so.0.1.0 libavahi-ui.so )
( cd usr/lib ; rm -rf libhowl.so.0 )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so.0 )
( cd usr/lib ; rm -rf libavahi-common.so )
( cd usr/lib ; ln -sf libavahi-common.so.3.5.0 libavahi-common.so )
( cd usr/lib ; rm -rf libavahi-glib.so.1 )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so.1 )
( cd usr/lib ; rm -rf libavahi-ui.so.0 )
( cd usr/lib ; ln -sf libavahi-ui.so.0.1.0 libavahi-ui.so.0 )
( cd usr/lib ; rm -rf libavahi-client.so.3 )
( cd usr/lib ; ln -sf libavahi-client.so.3.2.4 libavahi-client.so.3 )
( cd usr/lib ; rm -rf libhowl.so )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so )
( cd usr/lib ; rm -rf libdns_sd.so.1 )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so.1 )
( cd usr/lib ; rm -rf libavahi-glib.so )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so )
( cd usr/lib ; rm -rf libdns_sd.so )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so )
( cd usr/lib ; rm -rf libavahi-core.so.5 )
( cd usr/lib ; ln -sf libavahi-core.so.5.0.5 libavahi-core.so.5 )
( cd usr/lib ; rm -rf libavahi-core.so )
( cd usr/lib ; ln -sf libavahi-core.so.5.0.5 libavahi-core.so )
( cd usr/lib ; rm -rf libavahi-common.so.3 )
( cd usr/lib ; ln -sf libavahi-common.so.3.5.0 libavahi-common.so.3 )
( cd usr/lib ; rm -rf libavahi-client.so )
( cd usr/lib ; ln -sf libavahi-client.so.3.2.4 libavahi-client.so )
( cd usr/lib ; rm -rf libavahi-qt4.so )
( cd usr/lib ; ln -sf libavahi-qt4.so.1.0.2 libavahi-qt4.so )
( cd usr/lib ; rm -rf libavahi-gobject.so )
( cd usr/lib ; ln -sf libavahi-gobject.so.0.0.1 libavahi-gobject.so )
( cd usr/share/man/man1 ; rm -rf avahi-publish-service.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1.gz avahi-publish-service.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-browse-domains.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-browse.1.gz avahi-browse-domains.1.gz )
( cd usr/share/man/man1 ; rm -rf bvnc.1.gz )
( cd usr/share/man/man1 ; ln -sf bssh.1.gz bvnc.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-address.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1.gz avahi-resolve-address.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-host-name.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1.gz avahi-resolve-host-name.1.gz )
( cd usr/share/man/man1 ; rm -rf avahi-publish-address.1.gz )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1.gz avahi-publish-address.1.gz )
